/**
 * Stream Date View
 * @author Dominik Geng
 * @copyright 2018 Dominik Geng
 * @license Apache-2.0
 */
export declare class StreamDataView {
    /**
     * Creates a new instance of StreamDataView from a string.
     * e.g. from the string of toByteString()
     * @param str Byte string like '48 65 6C 6C 6F'
     * @return New instance of StreamDataView.
     */
    static fromByteString(str: string): StreamDataView;
    /**
     * Creates a new instance of StreamDataView from a string.
     * @param str Text string like 'Hello'
     * @param utf8 Handle the string as uft-8.
     * @return New instance of StreamDataView.
     */
    static fromTextString(str: string, utf8?: boolean): StreamDataView;
    private offset;
    private view;
    private littleEndian;
    private autoResize;
    /**
     * A buffer walker.
     * @param buffer Array buffer.
     * @param bigEndian Use big endian for numbers. (default: little endian)
     */
    constructor(buffer?: ArrayBuffer | number, bigEndian?: boolean);
    /**
     * Resize the buffer size.
     * NOTE: It creates a new buffer.
     * @param length New length of stream.
     */
    resize(length: number): void;
    /**
     * Crops the stream at its current offset.
     * e.g. You have a stream of 10 bytes but only 4 bytes used. (offset at 4).
     * This method uses the integrated resize-method.
     */
    crop(): void;
    /**
     * Returns the array buffer of the data view.
     * @return The buffer of this data view.
     */
    getBuffer(): ArrayBuffer;
    /**
     * Moves the offset relative in a direction.
     * @param length Positive or negative number byte length.
     */
    skip(length: number): void;
    /**
     * Moves the offset to zero.
     */
    resetOffset(): void;
    /**
     * Returns the current offset.
     * @return Offset
     */
    getOffset(): number;
    /**
     * Sets a new offset to an absolute position.
     * @param offset New offset (starts from zero)
     */
    setOffset(offset: number): void;
    /**
     * Reads a 8-bit singed integer.
     * @param offset Buffer offset.
     * @return INT8 value.
     */
    getInt8(offset: number): number;
    /**
     * Reads a 8-bit unsinged integer.
     * @param offset Buffer offset.
     * @return UINT8 value.
     */
    getUint8(offset: number): number;
    /**
     * Reads the next 8-bit singed integer from current offset.
     * @return INT8 value.
     */
    getNextInt8(): number;
    /**
     * Reads the next 8-bit unsinged integer from curret offset.
     * @return UINT8 value.
     */
    getNextUint8(): number;
    /**
     * Reads a 16-bit singed integer.
     * @param offset Buffer offset.
     * @return INT16 value.
     */
    getInt16(offset: number): number;
    /**
     * Reads a 16-bit unsinged integer.
     * @param offset Buffer offset.
     * @return UINT16 value.
     */
    getUint16(offset: number): number;
    /**
     * Reads the next 16-bit singed integer.
     * @return INT16 value.
     */
    getNextInt16(): number;
    /**
     * Reads the next 16-bit unsinged integer.
     * @return UINT16 value.
     */
    getNextUint16(): number;
    /**
     * Reads a 32-bit singed integer.
     * @param offset Buffer offset.
     * @return INT32 value.
     */
    getInt32(offset: number): number;
    /**
     * Reads a 32-bit unsinged integer.
     * @param offset Buffer offset.
     * @return UINT32 value.
     */
    getUint32(offset: number): number;
    /**
     * Reads the next 32-bit singed integer.
     * @return INT32 value.
     */
    getNextInt32(): number;
    /**
     * Reads the next 32-bit unsinged integer.
     * @return UINT32 value.
     */
    getNextUint32(): number;
    /**
     * Reads a float. (32-bit, signed)
     * @param offset Buffer offset.
     * @return FLOAT value.
     */
    getFloat32(offset: number): number;
    /**
     * Reads a double. (64-bit signed)
     * @param offset Buffer offset.
     * @return DOUBLE value.
     */
    getFloat64(offset: number): number;
    /**
     * Reads the next float. (32-bit, signed)
     * @return FLOAT value.
     */
    getNextFloat32(): number;
    /**
     * Reads the next double. (64-bit, signed)
     * @return DOUBLE value.
     */
    getNextFloat64(): number;
    /**
     * Writes a 8-bit signed integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setInt8(offset: number, value: number): void;
    /**
     * Writes a 8-bit unsigned integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setUint8(offset: number, value: number): void;
    /**
     * Writes the next 8-bit signed integer to the buffer.
     * @param value Value to write.
     */
    setNextInt8(value: number): void;
    /**
     * Writes the next 8-bit unsigned integer to the buffer.
     * @param value Value to write.
     */
    setNextUint8(value: number): void;
    /**
     * Writes a 16-bit signed integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setInt16(offset: number, value: number): void;
    /**
     * Writes a 16-bit unsigned integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setUint16(offset: number, value: number): void;
    /**
     * Writes the next 16-bit signed integer to the buffer.
     * @param value Value to write.
     */
    setNextInt16(value: number): void;
    /**
     * Writes the next 16-bit unsigned integer to the buffer.
     * @param value Value to write.
     */
    setNextUint16(value: number): void;
    /**
     * Writes a 32-bit signed integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setInt32(offset: number, value: number): void;
    /**
     * Writes a 32-bit unsigned integer to the buffer.
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setUint32(offset: number, value: number): void;
    /**
     * Writes the next 32-bit signed integer to the buffer.
     * @param value Value to write.
     */
    setNextInt32(value: number): void;
    /**
     * Writes the next 32-bit unsigned integer to the buffer.
     * @param value Value to write.
     */
    setNextUint32(value: number): void;
    /**
     * Writes a float to the buffer. (32-bit, signed)
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setFloat32(offset: number, value: number): void;
    /**
     * Writes a double to the buffer. (64-bit, signed)
     * @param offset Buffer offset.
     * @param value Value to write.
     */
    setFloat64(offset: number, value: number): void;
    /**
     * Writes the next float to the buffer. (32-bit, signed)
     * @param value Value to write.
     */
    setNextFloat32(value: number): void;
    /**
     * Writes the next double to the buffer. (64-bit, signed)
     * @param value Value to write.
     */
    setNextFloat64(value: number): void;
    /**
     * Reads an array of bytes.
     * @param offset Buffer offset.
     * @param length Buffer length.
     * @return Byte array like [42, 12, 255, 0]
     */
    getBytes(offset: number, length?: number): Uint8Array;
    /**
     * Reads the next array of bytes.
     * @param length Buffer length. (default: remaining length)
     * @return Byte array like [42, 12, 255, 0]
     */
    getNextBytes(length?: number): Uint8Array;
    /**
     * Writes a byte array to the buffer.
     * @param offset Buffer offset.
     * @param data Byte array to write.
     */
    setBytes(offset: number, data: Uint8Array): void;
    /**
     * Writes the next byte array to the buffer.
     * @param data Byte array to write.
     */
    setNextBytes(data: Uint8Array): void;
    /**
     * Reads a string from the buffer.
     * @param offset Buffer offset.
     * @param length Buffer length.
     * @param utf8 Use utf-8 encoding. (default: ascii)
     * @param untilTerminator Only returns the string until zero terminator.
     * @return String as utf8 or ascii.
     */
    getString(offset: number, length: number, utf8?: boolean, untilTerminator?: boolean): string;
    /**
     * Returns a string from the buffer.
     * @param length Buffer length.
     * @param utf8 Use utf-8 encoding. (default: ascii)
     * @param untilTerminator Only returns the string until zero terminator. Does not affect the offset shifting.
     * @return String as utf8 or ascii.
     */
    getNextString(length: number, utf8?: boolean, untilTerminator?: boolean): string;
    /**
     * Sets a string to the buffer.
     * @param offset Buffer offset.
     * @param data Data to write.
     * @param utf8 Use utf-8. (default: ascii)
     * @param length Optional fixed length write on buffer.
     * @return The the length in byte of the string. Useful for dynamic length.
     */
    setString(offset: number, data: string, utf8?: boolean, length?: number): number;
    /**
     * Sets a string to the buffer.
     * @param data Data to write.
     * @param utf8 Use uff-8. (default: ascii)
     * @param length Optional fixed length write on buffer.
     */
    setNextString(data: string, utf8?: boolean, length?: number): void;
    /**
     * Converts the buffer to a pretty print byte string.
     * @return Byte string like '48 65 6C 6C 6F'.
     */
    toByteString(): string;
    /**
     * Converts the buffer to a text string.
     * @param utf8 Handle it as UTF8 string otherwise ASCII.
     * @return Text string as utf8 or ascii.
     */
    toTextString(utf8?: boolean): string;
    /**
     * Parses a string of bytes like '48 65 6C 6C 6F'.
     * Also see the method 'toByteString'.
     * @param str Byte string.
     */
    fromByteString(str: string): void;
    private handleAutoResize;
}
